@@ -261,7 +261,7 @@ class Vapid01(object):
     def _base_sign(self, claims):
         cclaims = copy.deepcopy(claims)
         if not cclaims.get('exp'):
-            cclaims['exp'] = str(int(time.time()) + 86400)
+            cclaims['exp'] = int(time.time()) + 86400
         if not self.conf.get('no-strict', False):
             valid = _check_sub(cclaims.get('sub', ''))
         else:
@@ -277,7 +277,6 @@ class Vapid01(object):
                 "Missing 'aud' from claims. "
                 "'aud' is the scheme, host and optional port for this "
                 "transaction e.g. https://example.com:8080")
-
         return cclaims
 
     def sign(self, claims, crypto_key=None):
@@ -352,7 +351,7 @@ class Vapid02(Vapid01):
 
 def _check_sub(sub):
     pattern =(
-        r"^(mailto:.+@((localhost|[%\w]+(\.[%\w]+)+|([0-9a-f]{1,4}):+([0-9a-f]{1,4})?)))|https:\/\/(localhost|\w+\.[\w\.]+|([0-9a-f]{1,4}:+)+([0-9a-f]{1,4})?)$"
+        r"^(mailto:.+@((localhost|[%\w-]+(\.[%\w-]+)+|([0-9a-f]{1,4}):+([0-9a-f]{1,4})?)))|https:\/\/(localhost|[\w-]+\.[\w\.-]+|([0-9a-f]{1,4}:+)+([0-9a-f]{1,4})?)$"
         )
     return re.match(pattern, sub, re.IGNORECASE) is not None
 
